pub struct QueryResult {
pub ids: Vec<u32>,
pub backend_used: &'static str,
pub elapsed: Duration,
}Expand description
Result of a ring query.
Fields
ids: Vec<u32>IDs of all vectors whose distance to the query falls within
[d - lambda, d + lambda]. IDs correspond to insertion order
(first inserted vector has ID 0).
backend_used: &'static strName of the backend that executed the query (e.g. "cpu", "wgpu", "cuda").
elapsed: DurationWall-clock time for the query (excluding dataset upload).